# Debugging

To enable verbose tracing output, use the `-vvv` flag when running prek:

```bash
prek run -vvv
```

Besides, every prek run it writes a log file to `~/.cache/prek/prek.log` by default. If you encounter issues, please include this log file when reporting bugs.
